カードリスト ｜ ヴァイスシュヴァルツ｜Weiβ Schwarz
Description: 超エンターテイメントTCG『ヴァイスシュヴァルツ』
Keywords: ヴァイスシュヴァルツ,Weiβ Schwarz,ブシロード,Bushiroad,トレーディングカードゲーム,TCG,魔法少女リリカルなのはStrikerS,魔法少女リリカルなのはA's,魔法少女リリカルなのは The MOVIE 1st,Fate/stay night,Fate/hollow ataraxia,Fate/Zero,魔界戦記ディスガイア,魔界戦記ディスガイア4,ダ・カーポ,D.C.,D.C.II,D.C.Ⅲ,リトルバスターズ,リトルバスターズ!EX,アニメ「リトルバスターズ！」,ペルソナ3,ペルソナ4,TVアニメ「ペルソナ４」,ゼロの使い魔,ゼロの使い魔Ｆ, らき☆すた,リトルバスターズ!エクスタシー,THE KING OF FIGHTERS,戦国BASARA,ＴＶアニメ 戦国BASARA弐,Phantom,CLANNAD,シャイニング・フォース イクサ,涼宮ハルヒの憂鬱,Angel Beats!,クドわふたー,禁書目録II,超電磁砲,灼眼のシャナ,Rewrite,Rewrite Harvest festa!,魔法少女まどか☆マギカ,宇宙をかける少女,舞-HiME,舞-乙HiME,日常,DOG DAYS,CANAAN,アイドルマスター,THE IDOLM@STER,THE IDOLM@STER Dearly Stars,アイドルマスター２,アニメ「アイドルマスター」,FAIRY TAIL,MELTY BLOOD,ヱヴァンゲリヲン新劇場版,探偵オペラ ミルキィホームズ,探偵オペラ ミルキィホームズ２ ,化物語,刀語,劇場版マクロスＦ,ギルティクラウン,ブラック★ロックシューター,戦姫絶唱シンフォギア,アクセル・ワールド,ソードアート・オンライン,ビビッドレッド・オペレーション,初音ミク -Project DIVA- f,PSYCHO-PASS サイコパス

#

## カードリスト

### 検索結果

1398 件該当しました。1～25件目を表示しています。

商品名：

≪1 2 3 4 5 6 7 8 9… 56≫

| #### 春先のどか(HOL/W104-P01) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：1000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー：- 【自】［(1) 手札の《ホロライブ》のキャラを1枚控え室に置く］ このカードが手札から舞台に置かれた時か舞台から控え室に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の山札を上から3枚まで見て、カードを1枚まで選び、手札に加え、残りのカードを控え室に置く。
| #### 溶けてなくなる前に IRyS(HOL/W104-P02) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：3 色： パワー：10000 ソウル： コスト：2 レアリティ：PR トリガー： 特徴：ホロライブ・ホロライブEnglish Project: HOPE フレーバー：- 【永】 相手のレベル3以上のキャラがいるなら、あなたの手札のこのカードのレベルを－1。 【自】 このカードが手札から舞台に置かれたターン中、このカードがアタックした時、あなたのキャラすべてに、そのターン中、パワーを＋2500し、次の能力を与える。『【自】 このカードのバトル相手が【リバース】した時、あなたは相手のクロックの上から1枚を、控え室に置いてよい。そうしたら、あなたはそのキャラをクロック置場に置く。』
| #### 溶けてなくなる前に IRyS(HOL/W104-P02S) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：3 色： パワー：10000 ソウル： コスト：2 レアリティ：PR トリガー： 特徴：ホロライブ・ホロライブEnglish Project: HOPE フレーバー：- 【永】 相手のレベル3以上のキャラがいるなら、あなたの手札のこのカードのレベルを－1。 【自】 このカードが手札から舞台に置かれたターン中、このカードがアタックした時、あなたのキャラすべてに、そのターン中、パワーを＋2500し、次の能力を与える。『【自】 このカードのバトル相手が【リバース】した時、あなたは相手のクロックの上から1枚を、控え室に置いてよい。そうしたら、あなたはそのキャラをクロック置場に置く。』
| #### 決めポーズ☆ AZKi(HOL/W104-P03) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：3500 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・0期生 フレーバー：- 【永】 相手のキャラすべてに、『【自】 アンコール ［(2)］』を与える。 【自】［(1) 手札を1枚控え室に置く］ このカードが手札から舞台に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の山札を見て《ホロライブ》のキャラを1枚まで選んで相手に見せ、手札に加え、その山札をシャッフルする。
| #### 決めポーズ☆ AZKi(HOL/W104-P03S) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：3500 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・0期生 フレーバー：- 【永】 相手のキャラすべてに、『【自】 アンコール ［(2)］』を与える。 【自】［(1) 手札を1枚控え室に置く］ このカードが手札から舞台に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の山札を見て《ホロライブ》のキャラを1枚まで選んで相手に見せ、手札に加え、その山札をシャッフルする。
| #### 事務所スタッフ 友人A(HOL/W104-P04) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー：- 【自】 このカードが手札から舞台に置かれた時、他のあなたの《ホロライブ》のキャラがいるなら、あなたは自分の手札を2枚まで選び、ストック置場に好きな順番で置く。 【自】 このカードが手札から舞台に置かれた時、そのターン中、このカードのパワーを＋1500。
| #### 事務所スタッフ 友人A(HOL/W104-P04S) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー：- 【自】 このカードが手札から舞台に置かれた時、他のあなたの《ホロライブ》のキャラがいるなら、あなたは自分の手札を2枚まで選び、ストック置場に好きな順番で置く。 【自】 このカードが手札から舞台に置かれた時、そのターン中、このカードのパワーを＋1500。
| #### Vのすこんなオタ活なんだワ！(HOL/W104-P06) -PRカード【Wサイド】 サイド： 種類：クライマックス レベル：- 色： パワー：- ソウル：- コスト：- レアリティ：PR トリガー： 特徴：- フレーバー：- 【永】 あなたのキャラすべてに、パワーを＋1000し、ソウルを＋1。 （：このカードがトリガーした時、あなたは自分の控え室のキャラを1枚選び、手札に戻してよい）
| #### 星降る夜に(HOL/W104-P07) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー：- 【自】 他のあなたの《ホロライブ》のキャラがアタックした時、そのターン中、このカードのパワーを＋1000。 【自】［(1) 手札のクライマックスを1枚控え室に置く］ このカードが舞台から控え室に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の控え室のクライマックスを1枚選び、手札に戻す。
| #### 星降る夜に(HOL/W104-P07S) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー： 【自】 他のあなたの《ホロライブ》のキャラがアタックした時、そのターン中、このカードのパワーを＋1000。 【自】［(1) 手札のクライマックスを1枚控え室に置く］ このカードが舞台から控え室に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の控え室のクライマックスを1枚選び、手札に戻す。
| #### 友人A(HOL/W91-P02) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ フレーバー： 【永】あなたのストックが2枚以下なら、このカードのパワーを＋1500。 【永】あなたのターン中、他のあなたの《ホロライブ》のキャラすべてに、パワーを＋500。
| #### ゆびゆび～ 戌神ころね(HOL/W91-P03) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：1 色： パワー：3500 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・ゲーマーズ フレーバー：- 【永】あなたのキャラすべてが《ホロライブ》なら、このカードのパワーを＋3000。 【永】 このカードの下にマーカーがあるなら、このカードのパワーを＋2000。 【自】 このカードが手札から舞台に置かれた時、あなたは自分の手札を1枚選び、このカードの下にマーカーとして表向きに置いてよい。
| #### #花咲くホロライブ(HOL/W91-P04) -PRカード【Wサイド】 サイド： 種類：クライマックス レベル：- 色： パワー：- ソウル：- コスト：- レアリティ：PR トリガー： 特徴：- フレーバー：- 【永】 あなたのキャラすべてに、パワーを＋1000し、ソウルを＋1。 （：このカードがトリガーした時、あなたは自分の控え室のクライマックスを1枚選び、手札に戻してよい）
| #### 一緒にファイト♪ ときのそら&獅白ぼたん(HOL/W91-P05) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：2 色： パワー：3500 ソウル： コスト：1 レアリティ：PR トリガー： 特徴：ホロライブ フレーバー： 【永】 あなたのターン中、このカードのパワーを＋10000。
| #### こんばんみぉーん！ 大神ミオ(HOL/W91-P06) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2000 ソウル： コスト：0 レアリティ：PR トリガー：－ 特徴：ホロライブ・ゲーマーズ フレーバー：- 【自】 このカードが手札から舞台に置かれた時、そのターン中、このカードのパワーを＋Ｘ。Ｘはあなたの《ホロライブ》のキャラの枚数×1000に等しい。
| #### 一緒にファイト♪ 潤羽るしあ&兎田ぺこら&宝鐘マリン(HOL/W91-P07) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：1000 ソウル： コスト：0 レアリティ：PR トリガー：－ 特徴：ホロライブ・3期生 フレーバー：- 【自】［(1) 手札の《ホロライブ》のキャラを1枚控え室に置く］ このカードが手札から舞台に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の山札を上から4枚まで見て、カードを1枚まで選び、手札に加え、残りのカードを控え室に置く。
| #### くまのぬいぐるみ あん肝(HOL/WE36-P01) -PRカード【Wサイド】 サイド： 種類：イベント レベル：3 色： パワー：- ソウル：- コスト：1 レアリティ：PR トリガー：－ 特徴：- フレーバー：- このカードは、あなたの《ホロライブ》のキャラがいないなら、手札からプレイできない。 あなたは相手のレベル3以下のキャラを1枚選び、控え室に置く。
| #### 夢の中 アキ・ローゼンタール(HOL/WE44-P01) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：3 色： パワー：8000 ソウル： コスト：2 レアリティ：PR トリガー： 特徴：ホロライブ・1期生 フレーバー：すごくない、この夢？ 【永】 あなたの手札が1枚以下なら、このカードのパワーを＋10000。 【永】 大活躍 （相手がアタックする時、【リバース】していないこのカードが前列の中央の枠にいるなら、かわりに相手はこのカードにフロントアタックする） 【自】［手札を3枚控え室に置く］ このカードがアタックした時、あなたはコストを払ってよい。そうしたら、あなたは相手のキャラを1枚選び、控え室に置く。
| #### 一緒にトレーニング！ 天音かなた(HOL/WE44-P02) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：3000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・4期生 フレーバー：- 【永】 このカードはサイドアタックできない。 【自】 このカードのバトル相手が【リバース】した時、あなたは他の自分の《ホロライブ》のキャラを1枚選び、【レスト】し、後列のキャラのいない枠に動かす。
| #### 一緒にトレーニング！ 大空スバル(HOL/WE44-P03) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：2 色： パワー：6000 ソウル： コスト：1 レアリティ：PR トリガー： 特徴：ホロライブ・2期生 フレーバー：- 【永】 他のあなたの後列の《ホロライブ》のキャラ1枚につき、このカードのパワーを＋2000。 【自】 経験 このカードのバトル相手が【リバース】した時、あなたのレベル置場に、赤のカードと青のカードがあるなら、あなたは自分の山札の上から1枚を公開する。そのカードのレベルが1以上なら手札に加える。（CXのレベルは0として扱う。そうでないなら元に戻す）
| #### この世のものは脆すぎる 天音かなた(HOL/WE44-P04) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：2 色： パワー：7000 ソウル： コスト：1 レアリティ：PR トリガー： 特徴：ホロライブ・4期生 フレーバー：- 【自】 このカードがアタックした時、そのターン中、このカードのパワーを＋Ｘ。Ｘは他のあなたの《ホロライブ》のキャラの枚数×1000に等しい。 【自】［(1)］ 相手のアタックフェイズの始めに、あなたはコストを払ってよい。そうしたら、あなたは自分の《ホロライブ》のキャラを1枚とこのカードを選び、それぞれを【スタンド】して入れ替える。
| #### 一緒にトレーニング！ アキ・ローゼンタール(HOL/WE44-P05) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：2500 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・1期生 フレーバー：- 【自】［(1) あなたの控え室の《ホロライブ》のキャラを1枚クロック置場の下に置く］ このカードが舞台から控え室に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の控え室の《ホロライブ》のキャラを1枚選び、手札に戻す。
| #### 運動後の栄養補給 アキ・ローゼンタール(HOL/WE44-P06) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：2 色： パワー：6500 ソウル： コスト：1 レアリティ：PR トリガー： 特徴：ホロライブ・1期生 フレーバー：- 【自】 このカードがアタックした時、このカードの正面のキャラのレベルが3以上なら、そのターン中、このカードのパワーを＋6000。 【自】 このカードのバトル相手が【リバース】した時、あなたのCX置場にCXがあるなら、あなたは自分の山札を見て《ホロライブ》のキャラを1枚まで選んで相手に見せ、手札に加え、その山札をシャッフルする。
| #### 煌めく汗 大空スバル(HOL/WE44-P07) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：500 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・2期生 フレーバー：- 【永】 前列の中央の枠にこのカードがいるなら、このカードのパワーを＋3000。 【自】［(1) あなたの控え室の《ホロライブ》のキャラを1枚クロック置場の下に置く］ このカードが舞台から控え室に置かれた時、あなたはコストを払ってよい。そうしたら、あなたは自分の山札を上から2枚まで見て、《ホロライブ》のキャラを2枚まで選んで相手に見せ、手札に加え、残りのカードを控え室に置く。
| #### 一緒にトレーニング！ 白銀ノエル(HOL/WE44-P08) -PRカード【Wサイド】 サイド： 種類：キャラ レベル：0 色： パワー：1000 ソウル： コスト：0 レアリティ：PR トリガー：- 特徴：ホロライブ・3期生 フレーバー：- 【永】 応援 このカードの前のあなたのキャラすべてに、パワーを＋500。 【自】【CXコンボ】［あなたのCX置場の「団長と一緒」を1枚控え室に置く］ あなたのアンコールステップの始めに、あなたはコストを払ってよい。そうしたら、あなたは自分の山札の上から3枚までを、控え室に置き、自分の控え室のレベルＸ以下の《ホロライブ》のキャラを1枚まで選び、手札に戻す。Ｘはこの効果で控え室に置かれた《ホロライブ》のキャラの枚数に等しい。

≪1 2 3 4 5 6 7 8 9… 56≫

### 検索条件

キーワード | を含む [ 詳細検索 ] のいずれかを含む を含まない
検索対象： 名前 特徴 テキスト カード番号
ヴァイス・シュヴァルツサイド |
ネオスタンダード区分 |
商品名 | カテゴリ：
カード種類 |  | レベル | ～
パワー範囲 | ～ | 色 |
ソウル | ～ | コスト範囲 | ～
トリガー |  | オプション | カウンター クロック
表示件数 | 簡易表示 | パラレル | パラレルを除く

カードリストのトップに戻る

ページの先頭に戻る